/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.configuration.admin.definition;

import java.util.List;
import java.util.Locale;

/**
 * @author Alejandro Tardín  Provides option labels and values for configuration
 *         fields. Implementing this interface has the same effect as defining
 *         values for {@link aQute.bnd.annotation.metatype.Meta.AD.optionLabels}
 *         and {@link aQute.bnd.annotation.metatype.Meta.AD.optionValues} with
 *         the benefit of doing it at runtime.  Implementations must be
 *         registered as a ConfigurationFieldOptionsProvider service, and must
 *         have the property "configuration.pid" whose value matches the ID of
 *         the corresponding configuration interface (usually the fully
 *         qualified class name) and the property "configuration.field.name"
 *         whose value matches the name of the attribute in the configuration
 *         interface.
 * @review
 */
public interface ConfigurationFieldOptionsProvider {

	public List<Option> getOptions();

	public interface Option {

		public String getLabel(Locale locale);

		public String getValue();

	}

}